Packet

Struct Packet 

pub struct Packet {
    pub data: Buffer,
    pub pts: i64,
    pub dts: i64,
    pub duration: i64,
    pub stream_index: usize,
    pub flags: PacketFlags,
    pub pos: i64,
    pub side_data: Vec<PacketSideData>,
    pub trim_start: u32,
    pub trim_end: u32,
}
Encoded packet, matching FFmpeg’s AVPacket concept.

Fields

data: Buffer

Compressed data buffer.

pts: i64

Presentation timestamp in time_base units.

dts: i64

Decompression timestamp in time_base units.

duration: i64

Duration in time_base units.

stream_index: usize

Stream index this packet belongs to.

flags: PacketFlagspos: i64

Position in the stream (byte offset), or -1 if unknown.

side_data: Vec<PacketSideData>trim_start: u32

Number of decoded samples to trim from the start of the decoded packet (encoder delay / priming). Used for gapless playback.

trim_end: u32

Number of decoded samples to trim from the end of the decoded packet (encoder padding). Used for gapless playback.

Implementations

Source

impl Packet

pub fn new() -> Self

Create a new empty packet.

pub fn from_slice(data: &[u8]) -> Self

Create a packet from raw data.

pub fn size(&self) -> usize

Get the size of the packet data.